@@ -1,4 +1,5 @@
 #include <iostream>
+#include <cassert>
 #include "isoSpec++.h"
 
 using namespace IsoSpec;
@@ -12,13 +13,19 @@ int main(int argc, char** argv)
 	{
 		std::cout << "Proper usage (for example): " << argv[0] << " C10000H1000O1000N1000 0.9999" << std::endl;
 		std::cout << "...will print the minimal number of configurations necessary to cover 0.9999 probability of the above molecule" << std::endl;
+                std::cout << argv[0] << " C10000H1000O1000N1000 0.9999 false" << std::endl;
+                std::cout << "will just count them" << std::endl;
 		return -1;
 	}
+        bool print_confs = true;
+
+        if(argc > 3)
+            print_confs = (strcmp(argv[3], "true") == 0);
 	
 	#ifndef ISOSPEC_TESTS_MEMSAN
 	size_t no_confs = 
 	#endif 
-			  test_ordered(argv[1], atof(argv[2]), true);
+			  test_ordered(argv[1], atof(argv[2]), print_confs);
 
 	#ifndef ISOSPEC_TESTS_MEMSAN
 	std::cout << "The number of visited configurations is: " << no_confs << std::endl;
@@ -35,9 +42,13 @@ size_t test_ordered(const char* formula, double total_prob, bool print_confs)
 
 	size_t no_visited = 0;
         int* space = new int[i.getAllDim()];
+        double last_p = 1.0;
 	while(target_prob > 0.0 && i.advanceToNextConfiguration())
 	{
-		target_prob -= i.prob();
+                double curr_p = i.prob();
+                assert(last_p >= curr_p);
+                last_p = curr_p;
+		target_prob -= curr_p;
 		no_visited += 1;
 		if(print_confs)
 		{
